about summary refs log tree commit diff
diff options
context:
space:
mode:
authorTrevor Spiteri <trevor.spiteri@um.edu.mt>2019-01-07 14:27:50 +0100
committerTrevor Spiteri <trevor.spiteri@um.edu.mt>2019-01-07 14:27:50 +0100
commitd2ac094c99993d0bf3be2b480bf63605f1b39ab3 (patch)
treefec5abd850936b5f4eb61bd2a01cd68901799caa
parentaa257ec73ed96782821fc90e3aa9698813fa8385 (diff)
downloadrust-d2ac094c99993d0bf3be2b480bf63605f1b39ab3.tar.gz
rust-d2ac094c99993d0bf3be2b480bf63605f1b39ab3.zip
Update static files code for updated Source Serif Pro font
-rw-r--r--src/librustdoc/html/render.rs10
-rw-r--r--src/librustdoc/html/static_files.rs21
2 files changed, 12 insertions, 19 deletions
diff --git a/src/librustdoc/html/render.rs b/src/librustdoc/html/render.rs
index 184d5b24d6e..b48951d7593 100644
--- a/src/librustdoc/html/render.rs
+++ b/src/librustdoc/html/render.rs
@@ -893,14 +893,12 @@ themePicker.onblur = handleThemeButtonsBlur;
           static_files::fira_sans::MEDIUM)?;
     write(cx.dst.join("FiraSans-LICENSE.txt"),
           static_files::fira_sans::LICENSE)?;
-    write(cx.dst.join("Heuristica-Italic.woff"),
-          static_files::heuristica::ITALIC)?;
-    write(cx.dst.join("Heuristica-LICENSE.txt"),
-          static_files::heuristica::LICENSE)?;
-    write(cx.dst.join("SourceSerifPro-Regular.woff"),
+    write(cx.dst.join("SourceSerifPro-Regular.ttf.woff"),
           static_files::source_serif_pro::REGULAR)?;
-    write(cx.dst.join("SourceSerifPro-Bold.woff"),
+    write(cx.dst.join("SourceSerifPro-Bold.ttf.woff"),
           static_files::source_serif_pro::BOLD)?;
+    write(cx.dst.join("SourceSerifPro-It.ttf.woff"),
+          static_files::source_serif_pro::ITALIC)?;
     write(cx.dst.join("SourceSerifPro-LICENSE.txt"),
           static_files::source_serif_pro::LICENSE)?;
     write(cx.dst.join("SourceCodePro-Regular.woff"),
diff --git a/src/librustdoc/html/static_files.rs b/src/librustdoc/html/static_files.rs
index 47629d058e3..f340590e5fe 100644
--- a/src/librustdoc/html/static_files.rs
+++ b/src/librustdoc/html/static_files.rs
@@ -73,22 +73,17 @@ pub mod fira_sans {
     pub static LICENSE: &'static [u8] = include_bytes!("static/FiraSans-LICENSE.txt");
 }
 
-/// Files related to the Heuristica font.
-pub mod heuristica {
-    /// The file `Heuristica-Italic.woff`, the Italic variant of the Heuristica font.
-    pub static ITALIC: &'static [u8] = include_bytes!("static/Heuristica-Italic.woff");
-
-    /// The file `Heuristica-LICENSE.txt`, the license text for the Heuristica font.
-    pub static LICENSE: &'static [u8] = include_bytes!("static/Heuristica-LICENSE.txt");
-}
-
 /// Files related to the Source Serif Pro font.
 pub mod source_serif_pro {
-    /// The file `SourceSerifPro-Regular.woff`, the Regular variant of the Source Serif Pro font.
-    pub static REGULAR: &'static [u8] = include_bytes!("static/SourceSerifPro-Regular.woff");
+    /// The file `SourceSerifPro-Regular.ttf.woff`, the Regular variant of the Source Serif Pro
+    /// font.
+    pub static REGULAR: &'static [u8] = include_bytes!("static/SourceSerifPro-Regular.ttf.woff");
+
+    /// The file `SourceSerifPro-Bold.ttf.woff`, the Bold variant of the Source Serif Pro font.
+    pub static BOLD: &'static [u8] = include_bytes!("static/SourceSerifPro-Bold.ttf.woff");
 
-    /// The file `SourceSerifPro-Bold.woff`, the Bold variant of the Source Serif Pro font.
-    pub static BOLD: &'static [u8] = include_bytes!("static/SourceSerifPro-Bold.woff");
+    /// The file `SourceSerifPro-It.ttf.woff`, the Italic variant of the Source Serif Pro font.
+    pub static ITALIC: &'static [u8] = include_bytes!("static/SourceSerifPro-It.ttf.woff");
 
     /// The file `SourceSerifPro-LICENSE.txt`, the license text for the Source Serif Pro font.
     pub static LICENSE: &'static [u8] = include_bytes!("static/SourceSerifPro-LICENSE.txt");